import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/transfer-panel/vue';
import Checkbox from '@opentinyvue/vue-checkbox';
import Input from '@opentinyvue/vue-input';
import Pager from '@opentinyvue/vue-pager';
import { iconArrowDown, iconArrowUp, iconYes, iconSearch } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var transferPanelProps = {
  columns: Array,
  data: {
    type: Array,
    default: function _default() {
      return [];
    }
  },
  defaultChecked: Array,
  filterMethod: Function,
  filterable: Boolean,
  format: Object,
  isToLeft: Boolean,
  optionRender: Function,
  pagerOp: Object,
  placeholder: String,
  props: Object,
  render: Object,
  renderContent: Function,
  showLeft: Boolean,
  showPager: Boolean,
  title: String,
  treeOp: Object,
  value: {
    type: Array,
    default: function _default2() {
      return [];
    }
  }
};
var __vue2_script = defineComponent({
  name: $prefix + "TransferPanel",
  componentName: "TransferPanel",
  inheritAttrs: false,
  components: {
    TinyCheckbox: Checkbox,
    TinyInput: Input,
    TinyPager: Pager,
    IconArrowDown: iconArrowDown(),
    IconArrowUp: iconArrowUp(),
    IconCheckedSur: iconYes(),
    IconCheck: iconYes(),
    IconSearch: iconSearch(),
    OptionContent: {
      props: {
        option: [Object, Array]
      },
      render: function render() {
        return this.option;
      }
    }
  },
  props: transferPanelProps,
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render2 = function render3() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-transfer-panel",
    class: [_vm.state.renderType === "TinyTable" ? "transferGrid" : ""]
  }, [_c("p", {
    staticClass: "tiny-transfer-panel__header"
  }, [_c("tiny-checkbox", {
    attrs: {
      "indeterminate": _vm.state.isIndeterminate
    },
    on: {
      "change": _vm.handleAllCheckedChange
    },
    model: {
      value: _vm.state.allChecked,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "allChecked", $$v);
      },
      expression: "state.allChecked"
    }
  }, [_vm._v(" " + _vm._s(_vm.title) + " "), _vm.render && _vm.state.renderType !== "TinyTable" && _vm.data.flag === "sort" ? _c("div", {
    staticClass: "headSort"
  }, [_c("div", {
    staticClass: "sort-btn disabled up",
    on: {
      "click": function click($event) {
        return _vm.setPosition("up", $event);
      }
    }
  }, [_c("icon-arrow-up")], 1), _c("div", {
    staticClass: "sort-btn disabled down",
    on: {
      "click": function click($event) {
        return _vm.setPosition("down", $event);
      }
    }
  }, [_c("icon-arrow-down")], 1)]) : _vm._e(), _c("span", [_vm._v(_vm._s(_vm.state.checkedSummary))])])], 1), _c("div", {
    ref: "reference",
    class: ["tiny-transfer-panel__body", _vm.state.hasFooter ? "is-with-footer" : ""]
  }, [_vm.filterable ? _c("tiny-input", {
    staticClass: "tiny-transfer-panel__filter",
    attrs: {
      "size": "small",
      "placeholder": _vm.placeholder,
      "clearable": "",
      "inputBoxType": _vm.state.inputBoxType
    },
    on: {
      "clear": _vm.clearQuery,
      "mouseenter": function mouseenter($event) {
        _vm.state.inputHover = true;
      },
      "mouseleave": function mouseleave($event) {
        _vm.state.inputHover = false;
      }
    },
    scopedSlots: _vm._u([_vm.state.showInputSearch ? {
      key: "prefix",
      fn: function fn() {
        return [_c("icon-search")];
      },
      proxy: true
    } : null], null, true),
    model: {
      value: _vm.state.query,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "query", $$v);
      },
      expression: "state.query"
    }
  }) : _vm._e(), _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: !_vm.render,
      expression: "!render"
    }],
    staticClass: "tiny-checkbox-group tiny-transfer-panel__list",
    class: {
      "is-filterable": _vm.filterable
    },
    attrs: {
      "role": "group",
      "aria-label": "checkbox-group"
    }
  }, _vm._l(_vm.state.filteredData, function(item) {
    return _c("tiny-checkbox", {
      key: item[_vm.state.keyProp],
      staticClass: "tiny-transfer-panel__item",
      attrs: {
        "disabled": item[_vm.state.disabledProp],
        "checked": _vm.state.checked.length > 0 && _vm.state.checked.indexOf(item[_vm.state.keyProp]) > -1
      },
      on: {
        "change": function change($event) {
          return _vm.checkedEvent(item[_vm.state.keyProp], item[_vm.state.disabledProp]);
        }
      }
    }, [_c("option-content", {
      attrs: {
        "option": _vm.optionRender(item)
      }
    })], 1);
  }), 1), _vm.render && _vm.render.plugin ? _c(_vm.toRaw(_vm.render.plugin), _vm._g(_vm._b({
    ref: "plugin",
    tag: "component"
  }, "component", _vm.state.render, false), _vm.state.render.on)) : _vm._e(), _c("tiny-pager", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.showPager && _vm.state.renderType === "TinyTable",
      expression: "showPager && state.renderType === 'TinyTable'"
    }],
    ref: "pager",
    attrs: {
      "total": _vm.state.pagerTotal.length,
      "current-page": _vm.state.currentPage,
      "page-size": _vm.pagerOp.pageVO.pageSize,
      "layout": _vm.pagerOp.pageVO.layout,
      "page-sizes": _vm.pagerOp.pageVO.pageSizes,
      "mode": _vm.pagerOp.mode,
      "pager-count": _vm.pagerOp.pagerCount
    },
    on: {
      "size-change": _vm.sizesChange,
      "update:current-page": function updateCurrentPage($event) {
        _vm.state.currentPage = $event;
      },
      "current-change": _vm.handlePageChange
    }
  }), _c("p", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: !_vm.render && _vm.state.hasNoMatch,
      expression: "!render && state.hasNoMatch"
    }],
    staticClass: "tiny-transfer-panel__empty"
  }, [_vm._v(" " + _vm._s(_vm.t("ui.transfer.noMatch")) + " ")]), _c("p", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: !_vm.render && _vm.data.length === 0 && !_vm.state.hasNoMatch,
      expression: "!render && data.length === 0 && !state.hasNoMatch"
    }],
    staticClass: "tiny-transfer-panel__empty"
  }, [_vm._v(" " + _vm._s(_vm.t("ui.transfer.noData")) + " ")])], 1), _vm.$parent.slots["left-footer"] || _vm.$parent.slots["right-footer"] ? _c("p", {
    staticClass: "tiny-transfer-panel__footer"
  }, [_vm._t("default")], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render2, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var TransferPanel = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.22.0";
TransferPanel.install = function(Vue) {
  Vue.component(TransferPanel.name, TransferPanel);
};
TransferPanel.version = version;

export { TransferPanel as default };
